==========
Examples
==========

.. toctree::
   :maxdepth: 2

   examples/annotate
   examples/distance
   examples/transform
   examples/explainability
   examples/supervised
   examples/unsupervised
